summaryrefslogtreecommitdiff
path: root/internal
diff options
context:
space:
mode:
Diffstat (limited to 'internal')
-rw-r--r--internal/gui/app.go12
-rw-r--r--internal/gui/audio_player.go2
2 files changed, 10 insertions, 4 deletions
diff --git a/internal/gui/audio_player.go b/internal/gui/audio_player.go
index f9d0ad7..4846615 100644
--- a/internal/gui/audio_player.go
+++ b/internal/gui/audio_player.go
@@ -51,7 +51,7 @@ func NewAudioPlayer() *AudioPlayer {
p.playButtonLabel.TextStyle = fyne.TextStyle{Bold: true}
p.playBackButton = ttwidget.NewButton("", p.onPlayBack)
- p.playBackButton.Icon = theme.MediaSkipNextIcon()
+ p.playBackButton.Icon = theme.MediaPlayIcon() // Same icon as front button
p.playBackLabel = widget.NewLabel("")
p.playBackLabel.TextStyle = fyne.TextStyle{Bold: true}
diff --git a/internal/gui/app.go b/internal/gui/app.go
index cb0a4fe..03d45aa 100644
--- a/internal/gui/app.go
+++ b/internal/gui/app.go
@@ -1536,8 +1536,9 @@ func (a *Application) onShowHotkeys() {
**r/р** Regenerate all
## Playback
**p/п** Play audio (front for bg-bg)
**P/П** Play back audio (bg-bg only)
**u/у** Toggle auto-play
## Export & Archive
@@ -2592,11 +2593,16 @@ func (a *Application) handleShortcutKey(key fyne.KeyName) {
}
a.onNextWord()
- case fyne.KeyP: // Play audio
+ case fyne.KeyP: // Play front audio
if a.currentAudioFile != "" {
a.audioPlayer.Play()
}
+ case fyne.KeySpace: // Play back audio (for bg-bg cards)
+ if a.currentAudioFileBack != "" {
+ a.audioPlayer.PlayBack()
+ }
+
case fyne.KeyX: // Export to APKG
a.onExportToAnki()
@@ -1536,8 +1536,9 @@ func (a *Application) onShowHotkeys() {
**r/р** Regenerate all
## Playback
-**p/п** Play audio (front for bg-bg)
-**P/П** Play back audio (bg-bg only)
+**p/п** Play front audio (or audio for en-bg)
+**Space** Play back audio (bg-bg only)
+**P/П** Legacy: Play back audio (bg-bg only, use Space instead)
**u/у** Toggle auto-play
## Export & Archive